@@ -3,8 +3,8 @@ from discord.ext import commands
 import re
 
 regex_discord_message_url = (
-    'https://(ptb.|canary.)?discord(app)?.com/channels/'
-    '(?P<guild>[0-9]{18})/(?P<channel>[0-9]{18})/(?P<message>[0-9]{18})'
+    '(?!<)https://(ptb.|canary.)?discord(app)?.com/channels/'
+    '(?P<guild>[0-9]{18})/(?P<channel>[0-9]{18})/(?P<message>[0-9]{18})(?!>)'
 )
 
 
@@ -22,8 +22,15 @@ class ExpandDiscordMessageUrl(commands.Cog):
 async def dispand(message):
     messages = await extract_message(message)
     for m in messages:
-        if message.content:
+        if m.content or m.attachments:
             await message.channel.send(embed=compose_embed(m))
+        # Send the second and subsequent attachments with embed (named 'embed') respectively:
+        for attachment in m.attachments[1:]:
+            embed = Embed()
+            embed.set_image(
+                url=attachment.proxy_url
+            )
+            await message.channel.send(embed=embed)
         for embed in m.embeds:
             await message.channel.send(embed=embed)
 
